@@ -1,12 +1,14 @@
 from .tables import commands as tables_commands
 from covid_cloud.cli.utils import assert_config
 from covid_cloud.client import *
+from covid_cloud.cli.auth.utils import assert_token
 
 
 @click.group()
 @click.pass_context
 def search(ctx):
     assert_config(ctx, 'search-url')
+    assert_token(ctx)
 
 
 @search.command()
